# pytroll-watchers

Utility functions and scripts to watch for new files on local or remote filesystems.

[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/pytroll/pytroll-watchers/main.svg)](https://results.pre-commit.ci/latest/github/pytroll/pytroll-watchers/main)
